Options

Struct Options 

pub struct Options {
Show 13 fields pub env_outputname: Option<PathBuf>, pub env_tokens: bool, pub env_struct: bool, pub env_jitbit: Option<String>, pub env_bitwise: BitwiseMode, pub env_continue: ContinueMode, pub env_rawsetglobals: bool, pub env_debug: bool, pub env_output: bool, pub env_expand: bool, pub env_target: Option<LuaVersion>, pub env_targetos: String, pub env_symbols: bool,
}
The compiler options for Clue

Fields

env_outputname: Option<PathBuf>

The path of the output file, if any

env_tokens: bool

Prints the tokens to stdout

env_struct: bool

Prints the AST to stdout

env_jitbit: Option<String>

DEPRECATED

The name of the varible the bits library is assigned to

env_bitwise: BitwiseMode

The mode to use for bitwise operations

env_continue: ContinueMode

The continue mode to use when compiling continue keywords

env_rawsetglobals: bool

Whether to use rawset(_G, …) instead of simply x = … for globals

env_debug: bool

Whether to print debug information

env_output: bool

Whether to print the output to stdout

env_expand: bool

Whether to print the preprocessed file

env_target: Option<LuaVersion>

The Lua version to target

env_targetos: String

The path to the output file

env_symbols: bool

Whether to print the symbol table

Implementations

Source

impl Options

pub fn preset(&mut self)

Applies the chosen preset to the options This should be called after env_jitbit or env_target is set to reflect the chosen preset