pub struct Options {Show 13 fields
pub env_outputname: Option<PathBuf>,
pub env_tokens: bool,
pub env_struct: bool,
pub env_jitbit: Option<String>,
pub env_bitwise: BitwiseMode,
pub env_continue: ContinueMode,
pub env_rawsetglobals: bool,
pub env_debug: bool,
pub env_output: bool,
pub env_expand: bool,
pub env_target: Option<LuaVersion>,
pub env_targetos: String,
pub env_symbols: bool,
}Expand description
The compiler options for Clue
Fields
env_outputname: Option<PathBuf>The path of the output file, if any
env_tokens: boolPrints the tokens to stdout
env_struct: boolPrints the AST to stdout
env_jitbit: Option<String>DEPRECATED
The name of the varible the bits library is assigned to
env_bitwise: BitwiseModeThe mode to use for bitwise operations
env_continue: ContinueModeThe continue mode to use when compiling continue keywords
env_rawsetglobals: boolWhether to use rawset(_G, …) instead of simply x = … for globals
env_debug: boolWhether to print debug information
env_output: boolWhether to print the output to stdout
env_expand: boolWhether to print the preprocessed file
env_target: Option<LuaVersion>The Lua version to target
env_targetos: StringThe path to the output file
env_symbols: boolWhether to print the symbol table
Implementations